==> nextcloud-27.1.7p0.tgz: nextcloud/apps/comments/l10n/ko.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "댓글",
    "You commented" : "댓글 남김",
    "{author} commented" : "{author} 님이 댓글 남김",
    "You commented on %1$s" : "%1$s에 댓글 남김",
    "You commented on {file}" : "{file}에 댓글 남김",
    "%1$s commented on %2$s" : "%2$s에 %1$s 님이 댓글 남김",
    "{author} commented on {file}" : "{author} 님이 {file}에 댓글 남김",
    "<strong>Comments</strong> for files" : "파일의 <strong>댓글</strong>",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "삭제된 계정이 게시한 “{file}”의 댓글에서 나를 언급함",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} 님이 “{file}”에 남긴 댓글에서 나를 언급함",
    "Files app plugin to add comments to files" : "파일에 댓글을 남기는 파일 앱 플러그인",
    "Edit comment" : "댓글 편집",
    "Delete comment" : "댓글 삭제",
    "Cancel edit" : "편집 취소",
    "New comment" : "새로운 댓글",
    "Write a comment …" : "댓글 쓰기 ...",
    "Post comment" : "댓글 게시",
    "@ for mentions, : for emoji, / for smart picker" : "@을 입력해 언급, :을 입력해 이모지 추가, /을 입력해 스마트 피커를 사용하십시오.",
    "Could not reload comments" : "댓글을 다시 불러올 수 없음",
    "No comments yet, start the conversation!" : "아직 댓글이 없습니다. 대화를 시작하십시오!",
    "No more messages" : "메시지 더 이상 없음",
    "Retry" : "다시 시도",
    "Failed to mark comments as read" : "댓글을 읽음 표시할 수 없음",
    "Unable to load the comments list" : "댓글 목록을 불러올 수 없음",
    "_1 new comment_::_{unread} new comments_" : ["새 댓글 {unread}개"],
    "Comment" : "설명",
    "An error occurred while trying to edit the comment" : "댓글을 편집하는 중 오류 발생",
    "Comment deleted" : "댓글이 삭제됨",
    "An error occurred while trying to delete the comment" : "댓글을 삭제하는 중 오류 발생",
    "An error occurred while trying to create the comment" : "댓글을 작성하는 중 오류 발생",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "삭제된 사용자가 남긴 “{file}”의 댓글에서 나를 언급함",
    "_%n unread comment_::_%n unread comments_" : ["읽지 않은 댓글 %n개"]
},
"nplurals=1; plural=0;");

==> nextcloud-30.0.14.tgz: nextcloud/apps/comments/l10n/ko.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "댓글",
    "You commented" : "댓글 남김",
    "{author} commented" : "{author} 님이 댓글 남김",
    "You commented on %1$s" : "%1$s에 댓글 남김",
    "You commented on {file}" : "{file}에 댓글 남김",
    "%1$s commented on %2$s" : "%2$s에 %1$s 님이 댓글 남김",
    "{author} commented on {file}" : "{author} 님이 {file}에 댓글 남김",
    "<strong>Comments</strong> for files" : "파일의 <strong>댓글</strong>",
    "Files" : "파일",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "삭제된 계정이 게시한 “{file}”의 댓글에서 나를 언급함",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} 님이 “{file}”에 남긴 댓글에서 나를 언급함",
    "Files app plugin to add comments to files" : "파일에 댓글을 남기는 파일 앱 플러그인",
    "Edit comment" : "댓글 편집",
    "Delete comment" : "댓글 삭제",
    "Cancel edit" : "편집 취소",
    "New comment" : "새로운 댓글",
    "Write a comment …" : "댓글 쓰기 ...",
    "Post comment" : "댓글 게시",
    "@ for mentions, : for emoji, / for smart picker" : "@을 입력해 언급, :을 입력해 이모지 추가, /을 입력해 스마트 피커를 사용하십시오.",
    "Could not reload comments" : "댓글을 다시 불러올 수 없음",
    "Failed to mark comments as read" : "댓글을 읽음 표시할 수 없음",
    "Unable to load the comments list" : "댓글 목록을 불러올 수 없음",
    "No comments yet, start the conversation!" : "아직 댓글이 없습니다. 대화를 시작하십시오!",
    "No more messages" : "메시지 더 이상 없음",
    "Retry" : "다시 시도",
    "_1 new comment_::_{unread} new comments_" : ["새 댓글 {unread}개"],
    "Comment" : "설명",
    "An error occurred while trying to edit the comment" : "댓글을 편집하는 중 오류 발생",
    "Comment deleted" : "댓글이 삭제됨",
    "An error occurred while trying to delete the comment" : "댓글을 삭제하는 중 오류 발생",
    "An error occurred while trying to create the comment" : "댓글을 작성하는 중 오류 발생"
},
"nplurals=1; plural=0;");
